/*
 * checkerberry test center - https://www.checkerberry.de
 *
 * Copyright (c) 2010 ConceptPeople consulting gmbh
 *
 * Lizenziert unter der EUPL, Version 1.1 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/software/page/eupl5
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.conceptpeople.checkerberry.db.example.dao;

import java.util.List;

import org.hibernate.criterion.DetachedCriteria;
import org.hibernate.criterion.Restrictions;
import org.springframework.orm.hibernate3.support.HibernateDaoSupport;

import de.conceptpeople.checkerberry.db.example.entities.Dish;

/**
 * DAO zum Zugriff auf die DISH-Entities.
 */
public class DishDao extends HibernateDaoSupport {

    /**
     * Liefert das eindeutige Gericht zurück.
     * 
     * @param description
     *            eindeutige Beschreibung des Gerichts.
     * @return eindeutiges Gericht oder <code>null</code>, wenn es kein
     *         entsprechendes Gericht gibt.
     */
    @SuppressWarnings("unchecked")
    public Dish getDish(String description) {
        DetachedCriteria criteria = DetachedCriteria.forClass(Dish.class);
        criteria.add(Restrictions.eq("description", description));

        List<Dish> dishes = getHibernateTemplate().findByCriteria(criteria);
        return dishes.isEmpty() ? null : dishes.get(0);
    }

    /**
     * Speichert das angegebenen Gericht.
     * 
     * @param dish
     *            zu speicherndes Gericht.
     */
    public void save(Dish dish) {
        getHibernateTemplate().saveOrUpdate(dish);
    }

    /**
     * Löscht das angegebenen Gericht.
     * 
     * @param dish
     *            zu löschendes Gericht.
     */
    public void delete(Dish dish) {
        getHibernateTemplate().delete(dish);
    }

    /**
     * Liefert alle Gerichte der Tabelle zurück.
     * 
     * @return Liste der Gerichte.
     */
    @SuppressWarnings("unchecked")
    public List<Dish> getDish() {
        DetachedCriteria criteria = DetachedCriteria.forClass(Dish.class);
        return getHibernateTemplate().findByCriteria(criteria);
    }
}
