/*
 * checkerberry test center - https://www.checkerberry.de
 *
 * Copyright (c) 2010 ConceptPeople consulting gmbh
 *
 * Lizenziert unter der EUPL, Version 1.1 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/software/page/eupl5
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.conceptpeople.checkerberry.db.example;

import de.conceptpeople.checkerberry.db.bridge.configuration.DbConfiguration;
import de.conceptpeople.checkerberry.db.bridge.configuration.DbConfigurationCallback;

/**
 * Beispiel-Implementierung eines Callbacks zur Manipulation der Konfiguration
 * mit einigen besonderen Einstellungen.
 */
public class ExampleCustomConfigurationCallback implements DbConfigurationCallback {

    /**
     * {@inheritDoc}.
     */
    public void configure(DbConfiguration configuration) {
        // Hiermit werden DTD-Id und ihr Ort spezifiziert
        configuration.setDatabaseDtd("-//ConceptPeople//DTD example-db 1.0//EN",
                "de/conceptpeople/checkerberry/db/example/example-db.dtd");

        // Zugriff von allen JDBC-URLS verbieten...
        configuration.addToAccessControlBlacklist("*");
        // ...und nur hsql:mem erlauben.
        configuration.addToAccessControlWhitelist("*hsqldb:mem*");

        // Die Tabelle USERDISHREL wird global ausgeschlossen, d.h. sie wird
        // überall ignoriert.
        configuration.addTablesToIgnoreList("USERDISHREL");

        // Die Dateiendungen für die Testdaten werden neu gesetzt.
        configuration.setInitialSuffix("initial_data");
        configuration.setExpectedSuffix("expected_data");

        // Testdaten werden jetzt nicht mehr unter
        // MyClass_testMethod_initial.xml gesucht, sondern unter
        // MyClassDirectory/testMethod/initial_data.xml
        configuration.setTestdataNameResolverPattern("{0}Directory/{1}/{2}.xml");
        configuration.setTestdataNameResolverMethodPrefix("");
        configuration.setTestdataNameResolverSuffixPrefix("");
    }
}
